@@ -48,10 +48,15 @@ private:
 
     int maxVol;
     int meter;
+
     QProcess *process;
     QStringList *sources;
+
+    int triggerCount;
+    int triggerCountSetting;
     int triggerValue;
     QString triggerCommand;
+
     VolumeMeterWidget *volumeMeterWidget;
 
     void getSettings();
