@@ -4,6 +4,7 @@
 #include <QSettings>
 
 QString SettingsDialog::AUTO_ROTATE = "auto_rotate";
+QString SettingsDialog::COLOR_SCALE = "color_scale";
 QString SettingsDialog::TRIGGER = "trigger";
 QString SettingsDialog::TRIGGER_COMMAND = SettingsDialog::TRIGGER + "/command";
 QString SettingsDialog::TRIGGER_COUNT = SettingsDialog::TRIGGER + "/count";
@@ -27,6 +28,8 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     ui->autoRotateCheckBox->close();
     ui->autoRotateLabel->close();
 #endif
+
+    ui->colorScaleSettingCheckBox->setChecked(settings.value(SettingsDialog::COLOR_SCALE, false).toBool());
 }
 
 SettingsDialog::~SettingsDialog()
@@ -45,6 +48,8 @@ void SettingsDialog::accept(){
     settings.setValue(SettingsDialog::AUTO_ROTATE, ui->autoRotateCheckBox->checkState());
 #endif
 
+    settings.setValue(SettingsDialog::COLOR_SCALE, ui->colorScaleSettingCheckBox->checkState());
+
     settings.sync();
 
     done(1);
