@@ -126,6 +126,11 @@ void VolumeMeterWidget::setTriggerValue(int value){
     emit update();
 }
 
+void VolumeMeterWidget::setUseColoredScale(bool b){
+    useColoredScale = b;
+    emit update();
+}
+
 void VolumeMeterWidget::updateValue(int value){
     currentValue = value;
     emit update();
